/* Ergo, version 3.4, a program for linear scaling electronic structure
 * calculations.
 * Copyright (C) 2014 Elias Rudberg, Emanuel H. Rubensson, and Pawel Salek.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Primary academic reference:
 * Kohn−Sham Density Functional Theory Electronic Structure Calculations 
 * with Linearly Scaling Computational Time and Memory Usage,
 * Elias Rudberg, Emanuel H. Rubensson, and Pawel Salek,
 * J. Chem. Theory Comput. 7, 340 (2011),
 * <http://dx.doi.org/10.1021/ct100611z>
 * 
 * For further information about Ergo, see <http://www.ergoscf.org>.
 */

#ifndef INTEGRALS_1EL_KINETIC
#define INTEGRALS_1EL_KINETIC


#include "basisinfo.h"


ergo_real simplePrimTintegral(const DistributionSpecStruct& prim1,
			      const DistributionSpecStruct& prim2,
			      int coord,
			      ergo_real threshold);

int compute_T_matrix_sparse(const BasisInfoStruct& basisInfo,
			    ergo_real threshold,
			    int n,
			    int* nvaluesList,
			    int** colindList,
			    ergo_real** valuesList);

int compute_T_matrix_full(const BasisInfoStruct& basisInfo,
			  ergo_real threshold,
			  ergo_real* result);


#endif
